/*
 * 本地化组件脚本，需要与label，spriteFrame等配合使用
 * @Author: sunqifeng 
 * @Date: 2019-02-17 18:45:45 
 * @Last Modified by: minanyang
 * @Last Modified time: 2019-04-29 17:38:31
 */

const { ccclass, property,executeInEditMode } = cc._decorator;
import ComponentBase from '../../System/ComponentBase';
import { LOCAL } from './LocalManager';
import GameTools from '../../Game/Tools/GameTools';

enum CPN_TYPE {
    NONE,
    LABEL,
    IMAGE,
    RICHTEXT
}

@ccclass
@executeInEditMode
export default class LocalComponent extends ComponentBase 
{
    @property(String)
    private langKey: string = "";
    //---------------
    protected _cpn_type: CPN_TYPE = CPN_TYPE.NONE;
    protected _texture: cc.Texture2D;
    protected _isAtlasMode: boolean = false;

    
    /** 获取当前节点上的label组件 */
    protected getLabel(): cc.Label
    {
        if (!this.node || !this.node.isValid)
            return null;
        return this.node.getComponent(cc.Label);
    }

    /** 获取当前节点上的sprite组件 */
    protected getRichText(): cc.RichText
    {
        if (!this.node || !this.node.isValid)
            return null;
        return this.node.getComponent(cc.RichText);
    }

    /** 获取当前节点上的sprite组件 */
    protected getSprite(): cc.Sprite
    {
        if (!this.node || !this.node.isValid)
            return null;
        return this.node.getComponent(cc.Sprite);
    }
    cpnLoad() {
        // if(CC_EDITOR) {
        //     if(this.langKey==null || this.langKey==undefined || this.langKey.length<1) return;
        //     let self = this;
        //     cc.loader.load(
        //     {
        //         url: "db://assets/resources/locale/zh_cn.txt",
        //         uuid: "4e5a23d8-60a3-401f-8396-06502b4b0cf0"
        //     }, 
        //     function (err, asset) {
        //         let rows = asset.text.split(/[\r\n]+/);
        //         let langData = new Map<string,string>();
        //         for(let i = 0;i < rows.length;i++) {
        //             let rowContent = rows[i];
        //             if(rowContent.indexOf("=")>0) {
        //                 langData.set(rowContent.substring(0,rowContent.indexOf("=")),rowContent.substring(rowContent.indexOf("=")+1,rowContent.length));
        //             }
        //         }
        //         let label:cc.Label = self.getLabel();
        //         let str = langData.get(self.langKey);
        //         if(str != undefined && str != null && str.length>1)
        //         {
        //             label.string = str;
        //         }
        //     }
        //     );
        // }
        if (this.getLabel()) {
            this._cpn_type = CPN_TYPE.LABEL;
            this.updateLabelString();
        } else if (this.getRichText()) {
            this._cpn_type = CPN_TYPE.RICHTEXT;
            this.updateLabelString();
        } else if (this.getSprite()) {
            this._cpn_type = CPN_TYPE.IMAGE;
        }
    }

    /** 进入时 */
    cpnEnable()
    {
        // if (this.getLabel()) {
        //     this._cpn_type = CPN_TYPE.LABEL;
        //     this.updateLabelString();
        // } else if (this.getSprite()) {
        //     this._cpn_type = CPN_TYPE.IMAGE;
        // }
    }

    updateLabelString()
    {
        if(this._cpn_type==CPN_TYPE.LABEL) {
            if(this.langKey==null || this.langKey==undefined || this.langKey.length<1) return;
            if(!LOCAL.IsLoaded) return;
            let label:cc.Label = this.getLabel();
            if(!GameTools.verifyComponent(label)) {
                return;
            }
            if(!CC_EDITOR && !LOCAL.canUseBMFont()) {
                label.isSystemFontUsed = true;
            }
            label.string = LOCAL.getText(this.langKey);
        }else if(this._cpn_type==CPN_TYPE.RICHTEXT)
        {
            if(this.langKey==null || this.langKey==undefined || this.langKey.length<1) return;
            if(!LOCAL.IsLoaded) return;
            let label:cc.RichText = this.getRichText();
            if(!GameTools.verifyComponent(label)) {
                return;
            }
            label.string = LOCAL.getText(this.langKey);
        }
    }

    public setLangKey(key:string) {
        this.langKey = key;
        this.updateLabelString();
    }

    /** 催毁组件时 */
    cpnDestroy()
    {
        
    }

    /** 尝试加载图片 */
    public loadImage(): void
    {

    }

  
}
